@@ -2,6 +2,7 @@ import os
 import re
 import numpy as np
 import pandas as pd
+from skimage import color, io
 import matplotlib.pyplot as plt
 import sklearn
 from tqdm import tqdm
@@ -21,7 +22,7 @@ modelImages = Sequential()
 shape = (28, 28, 3)
 images = pd.DataFrame()
 le = preprocessing.LabelEncoder()
-reImage = re.compile(r'.jpg$|.png$')
+re_image = re.compile(r'.jpg$|.png$')
 
 
 def load_test_data(training_file):
@@ -34,7 +35,6 @@ def load_test_data(training_file):
 
     Returns
     -------
-
     """
     global images
     images = pd.read_csv(training_file)
@@ -65,18 +65,15 @@ def build_model_manual(x, y):
     ----------
     x : ndarray
         numpy array of image data
-        
     y : Series.array
         numeric categories for each image
-        
 
     Returns
     -------
-
     """
     global modelImages
     classes = len(y[0])
-    
+
     modelImages = Sequential()
     modelImages.add(Conv2D(32, (3, 3), activation="relu", input_shape=shape))
     modelImages.add(Conv2D(64, (3, 3), activation="relu"))
@@ -96,17 +93,14 @@ def build_model_vgg16(x, y):
     ----------
     x : ndarray
         numpy array of image data
-        
     y : Series.array
         numeric categories for each image
-        
 
     Returns
     -------
-
     """
     global modelImages
-    
+
     classes = len(y[0])
     lr = 1e-6
     modelImages = VGG16(weights=None, input_shape=shape, classes=classes)
@@ -121,11 +115,9 @@ def predict(path):
     ----------
     path : str
         Path to a test image
-        
 
     Returns
     -------
-    keras predictions
     """
     test_image = []
     test = image.load_img(path, target_size=shape)
@@ -140,14 +132,11 @@ def predict_print(path, categories):
     ----------
     path : str
         Path to an image
-        
     categories : array
         array of categories to display
-        
 
     Returns
     -------
-
     """
     prediction = predict(path)
     for category in categories:
@@ -160,14 +149,12 @@ def print_category(prediction, category):
     Parameters
     ----------
     prediction : keras prediction
-        
+
     category : str
         category to test
-        
 
     Returns
     -------
-
     """
     classification = class_from_category(category)
     print(f"{category}: {prediction[0][classification] * 100:.0f}%")
@@ -180,7 +167,6 @@ def predict_category(path):
     ----------
     path : str
         Path to an image
-        
 
     Returns
     -------
@@ -198,7 +184,6 @@ def class_from_category(category):
     ----------
     category : str
         Text description of category as listed in training data
-        
 
     Returns
     -------
@@ -208,45 +193,51 @@ def class_from_category(category):
     return images[images['category'] == category]['class'].unique()[0]
 
 
-def find_category(path, category):
+def find_category(path, category, blacklist=""):
     """Given a directory, find all images predicted for a given category
 
     Parameters
     ----------
     path : str
         Folder to search
-        
     category : str
         Category of interest
-        
+    blacklist : str
+         (Default value = "")
+         expression defining file paths to skip
 
     Returns
     -------
     hits : array
         Array of files predicted to be in the given category
     """
+    re_blacklist = re.compile(blacklist)
+
     hits = []
     for folderName, subfolders, filenames in os.walk(path):
         for filename in filenames:
-            filePath = path + '\\' + filename
+            filePath = folderName + '\\' + filename
             filePath = filePath.lower()
 
-            if reImage.search(filePath) is None:
+            if re_image.search(filePath) is None:
                 continue
-            predicted = predict_category(filePath)[0]
+            if re_blacklist.search(filePath) is not None:
+                continue
+            print(filePath)
+            predicted = predict_category(filePath)
             if (predicted == category):
                 hits.append(filePath)
     return hits
 
 
 def find_best_fit(hits, category):
-    """Given a list of files predicted to be in a given category, find the file with the highest probability
+    """Given a list of files predicted to be in a given category,
+    find the file with the highest probability
 
     Parameters
     ----------
     hits : array of str
         List of files predicted to be in the category
-        
     category : str
         Category of predicted files
 
@@ -269,11 +260,27 @@ def find_best_fit(hits, category):
     return bestfile
 
 
-def find_best_fit_by_folder(path, category):
-    hits = find_category(path, category)
+def find_best_fit_by_folder(path, category, blacklist=""):
+    """Search a folder for images. Compare each image and return best fit.
+
+    Parameters
+    ----------
+    path : str
+
+    category :
+
+
+    blacklist : str
+         (Default value = "")
+         expression defining file paths to skip
+
+    Returns
+    -------
+    """
+    hits = find_category(path, category, blacklist)
     return find_best_fit(hits, category)
 
-    
+
 def show_image(image, title='Image', cmap_type='gray'):
     """Display the image
 
@@ -281,17 +288,17 @@ def show_image(image, title='Image', cmap_type='gray'):
     ----------
     image : str
         path to the image
-        
     title : str
-         (Default value = 'Image')
+        (Default value = 'Image')
     cmap_type :
-         (Default value = 'gray')
+        (Default value = 'gray')
 
     Returns
     -------
-
     """
-    plt.imshow(image, cmap=cmap_type)
+    bits = io.imread(image)
+    bits_grey = color.rgb2gray(bits)
+    plt.imshow(bits_grey, cmap=cmap_type)
     plt.title(title)
     plt.axis('off')
     plt.show()
